Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Enum UWireMetadataError

#[non_exhaustive]
pub enum UWireMetadataError { WrongMagic, UnknownMetadataLayoutId { actual: WireIdentityRef, }, UnsupportedVersion { expected: u16, actual: u16, }, WrongWireMetadata { expected: WireIdentity, actual: WireIdentityRef, }, PayloadFamilyMismatch { expected: WireIdentity, actual: WireIdentityRef, }, UnsupportedReservedFlags(u16), UnsupportedPayloadEncoding(String), MalformedMetadata(String), FrameMetadata(String), SerializationError(String), }
Errors returned by native-prefix selected-wire metadata handling.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


WrongMagic

The input did not start with the native-prefix metadata magic bytes.



UnknownMetadataLayoutId

The metadata layout id was not native-prefix.

Fields

actual: WireIdentityRef

The metadata layout id actually present in the input.



UnsupportedVersion

The metadata layout id that was actually present. The metadata version is unsupported by the selected wire.

Fields

expected: u16

The version this codec supports.

actual: u16

The version present in the input.



WrongWireMetadata

The selected-wire id is incompatible with W.

Fields

expected: WireIdentity

The selected wire’s identity.

actual: WireIdentityRef

The wire identity present in the input.



PayloadFamilyMismatch

The payload-family id is incompatible with W.

Fields

expected: WireIdentity

The selected wire’s payload-family identity.

actual: WireIdentityRef

The payload-family identity present in the input.



UnsupportedReservedFlags(u16)

The reserved flags field contained unsupported bits.



UnsupportedPayloadEncoding(String)

The payload encoding block is unsupported or malformed.



MalformedMetadata(String)

The metadata bytes are malformed.



FrameMetadata(String)

Frame metadata validation failed.



SerializationError(String)

Metadata serialization or parsing failed.