#[non_exhaustive]pub enum UWireMetadataError {
WrongMagic,
UnknownMetadataLayoutId {
actual: WireIdentityRef,
},
UnsupportedVersion {
expected: u16,
actual: u16,
},
WrongWireMetadata {
expected: WireIdentity,
actual: WireIdentityRef,
},
PayloadFamilyMismatch {
expected: WireIdentity,
actual: WireIdentityRef,
},
UnsupportedReservedFlags(u16),
UnsupportedPayloadEncoding(String),
MalformedMetadata(String),
FrameMetadata(String),
SerializationError(String),
}Expand description
Errors returned by native-prefix selected-wire metadata handling.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
WrongMagic
The input did not start with the native-prefix metadata magic bytes.
UnknownMetadataLayoutId
The metadata layout id was not native-prefix.
Fields
actual: WireIdentityRefThe metadata layout id actually present in the input.
UnsupportedVersion
The metadata layout id that was actually present. The metadata version is unsupported by the selected wire.
WrongWireMetadata
The selected-wire id is incompatible with W.
Fields
expected: WireIdentityThe selected wire’s identity.
actual: WireIdentityRefThe wire identity present in the input.
PayloadFamilyMismatch
The payload-family id is incompatible with W.
Fields
expected: WireIdentityThe selected wire’s payload-family identity.
actual: WireIdentityRefThe payload-family identity present in the input.
UnsupportedReservedFlags(u16)
The reserved flags field contained unsupported bits.
UnsupportedPayloadEncoding(String)
The payload encoding block is unsupported or malformed.
MalformedMetadata(String)
The metadata bytes are malformed.
FrameMetadata(String)
Frame metadata validation failed.
SerializationError(String)
Metadata serialization or parsing failed.